import asyncio
from urllib.parse import quote
from biblebot.reqeust.requests_conn import *


async def main():
    data = {"Txt_1": "ramming125", "Txt_2": "gksrlghd123", "use_type": "2"}
    resp = await Request.post(
        "https://kbuis.bible.ac.kr/ble_login2.aspx",
        body=data,
        verify=False,
        allow_redirects=False,
        timeout=20.0,
    )
    print(resp.text)
    print(resp.headers)
    cookies = resp.cookies
    print(cookies)

    resp = await Request.get(
        "http://kbuis.bible.ac.kr/SchoolRegMng/SR020.aspx", cookies=cookies
    )
    print(resp.text)


asyncio.run(main())



import asyncio

from biblebot.api.mileage import *
from biblebot.api._mileage import *

from biblebot.api.base import ErrorData, ResourceData

import biblebot


async def test_login():
    response = await Login.fetch("bible", "biblebot12")  # 아이디 없음
    assert response.status == 200
    result = Login.parse(response)
    assert isinstance(result, ErrorData)

    # response = await Login.fetch("bible", "biblebot12")  # 비밀번호 틀림
    # assert response.status == 200
    # result = Login.parse(response)
    # assert isinstance(result, ErrorData)

    response = await Login.fetch("bibleCS1", "biblebot12")  # 정
    assert response.status == 200
    result = Login.parse(response)
    assert isinstance(result, ResourceData)
    return result.data["cookies"]


async def test_search(cookies):
    response = await Search.fetch(cookies)
    assert response.status == 200
    result = Search.parse(response)
    assert len(result.data["body"]) > 0
    print("전체데이터", result)

    sid = "201504021"
    param = SearchParamData().set_student_id(sid)
    response = await Search.fetch(cookies, param)
    assert response.status == 200
    result = Search.parse(response)
    assert len(result.data["body"]) == 1
    i = result.data["head"].index("카드번호")
    assert result.data["body"][0][i] == sid
    print("학번 검색데이터", result)

    phone = ("010", "8714", "0965")
    param = SearchParamData().set_phone_number(*phone)
    response = await Search.fetch(cookies, param)
    assert response.status == 200
    result = Search.parse(response)
    assert len(result.data["body"]) == 1
    i = result.data["head"].index("회원명")
    assert result.data["body"][0][i] == "김태희"
    print("핸드폰 검색데이터", result)

    cid = "00001229"
    param = SearchParamData().set_customer_id(cid)
    response = await Search.fetch(cookies, param)
    assert response.status == 200
    result = Search.parse(response)
    assert len(result.data["body"]) == 1
    i = result.data["head"].index("회원번호")
    assert result.data["body"][0][i] == cid
    print("고객번호 검색데이터", result)

    page_size = "20"
    page_num = "2"
    param = SearchParamData().set_page_size(page_size).set_page_num(page_num)
    response = await Search.fetch(cookies, param)
    assert response.status == 200
    result = Search.parse(response)
    assert len(result.data["body"]) == int(page_size)
    print("페이지 사이즈 제한 검색데이터", result)


async def test_statement(cookies):
    response = await Statement.fetch(
        cookies, StatementParamData().set_customer_id("00001229")
    )
    assert response.status == 200
    result = Statement.parse(response)
    assert isinstance(result, ResourceData)
    print(result)


async def test_invalid_cookies():
    invalid_cookies = {"JSESSIONID": "8CF7F1D7CA5BF96A18D723DEB6230FDF"}
    response = await Search.fetch(invalid_cookies)
    assert response.status == 200
    result = Search.parse(response)
    assert isinstance(result, ErrorData)

    response = await Statement.fetch(
        invalid_cookies, StatementParamData().set_customer_id("00001229")
    )
    assert response.status == 200
    result = Statement.parse(response)
    assert isinstance(result, ErrorData)


async def main():
    cookies = await test_login()

    await test_search(cookies)
    await test_statement(cookies)

    await test_invalid_cookies()


asyncio.run(main())

# java.lang.NullPointerException
# java.lang.Exception: 9000╋세션정보가 없음.



import asyncio

from biblebot.api.intranet import *
from biblebot.api.base import ErrorData, ResourceData


async def test_login(user_id, user_pw):
    # 비밀번호 틀린 경우
    response = await Login.fetch(user_id, user_pw + "123")
    assert response.status == 200
    assert response.cookies
    result = Login.parse(response)
    assert isinstance(result, ErrorData)
    assert result.error["title"] == "비밀번호가 일치하지 않습니다."

    # 아이디가 다른 경우
    response = await Login.fetch(user_id + "1a2b3c", user_pw)
    assert response.status == 200
    assert response.cookies
    result = Login.parse(response)
    assert isinstance(result, ErrorData)
    assert result.error["title"] == "존재하지 않는 회원ID 입니다."

    # 정상 로그인
    response = await Login.fetch(user_id, user_pw)
    assert response.status == 302
    assert response.cookies
    result = Login.parse(response)
    assert isinstance(result, ResourceData)
    assert result.data["cookies"]
    assert result.data["iat"]

    return response


async def test_student_photo(cookies, sid):
    # 학번이 존재하지 않을 경우
    response = await StudentPhoto.fetch(cookies, "201509021")
    assert response.status == 200

    result = StudentPhoto.parse(response)
    assert isinstance(result, ErrorData)
    print(result)

    # 학번이 존재할 경우
    response = await StudentPhoto.fetch(cookies, sid)
    assert response.status == 200

    result = StudentPhoto.parse(response)
    assert isinstance(result, ResourceData)
    assert len(result.data["raw_image"]) > 100
    print(result)


async def test_chapel(cookies, semesters):
    for semester in semesters:
        response = await Chapel.fetch(cookies, semester=semester)
        assert response.status == 200
        result = Chapel.parse(response)
        assert isinstance(result, ResourceData)
        if semester:
            assert result.meta["selected"] == semester
        print(semester, result)


async def test_timetable(cookies, semesters):
    for semester in semesters:
        response = await Timetable.fetch(cookies, semester=semester)
        assert response.status == 200
        result = Timetable.parse(response)
        assert isinstance(result, ResourceData)
        if semester:
            assert result.meta["selected"] == semester
        print(semester, result)


async def test_course(cookies, semesters):
    for semester in semesters:
        response = await Course.fetch(cookies, semester=semester)
        assert response.status == 200
        result = Course.parse(response)
        assert isinstance(result, ResourceData)
        if semester:
            assert result.meta["selected"] == semester

        print(semester, result)


async def test_invalid_cookies():
    invalid_cookies = {"ASP.NET_SessionId": "hello"}
    response = await StudentPhoto.fetch(invalid_cookies, "201504021")
    result = StudentPhoto.parse(response)
    assert isinstance(result, ErrorData)

    response = await Chapel.fetch(invalid_cookies, semester="20191")
    assert response.status == 200
    result = Chapel.parse(response)
    assert isinstance(result, ErrorData)

    response = await Timetable.fetch(invalid_cookies, semester="20192")
    assert response.status == 200
    assert isinstance(result, ErrorData)

    response = await Course.fetch(invalid_cookies, semester="20201")
    assert response.status == 200
    result = Course.parse(response)
    assert isinstance(result, ErrorData)


async def main():
    semesters = (None, "20192", "20191", "20182", "20181", "20152", "20151")
    response = await test_login("ramming125", "gksrlghd123")
    # response.cookies["ASP.NET_SessionId"] = response.cookies["ASP.NET_SessionId"]
    # await test_student_photo(response.cookies, "201504021")
    await test_chapel(response.cookies, semesters)
    await test_timetable(response.cookies, semesters)
    await test_course(response.cookies, semesters)
    # await test_invalid_cookies()


asyncio.run(main())



import asyncio
import datetime

from urllib.parse import quote

from biblebot.api.kbu import *


def encode_kbustyle(str):
    return quote(str).replace("%20", "+")


async def test_main_notice():
    response = await MainNotice.fetch()
    assert response.status == 200

    result = MainNotice.parse(response)
    assert result.meta["page"] == "1"
    assert result.meta["keyword"] is None
    assert len(result.data["notice"]) == 20

    response = await MainNotice.fetch(page="2")
    assert response.status == 200

    result = MainNotice.parse(response)
    assert result.meta["page"] == "2"
    assert result.meta["keyword"] is None
    assert len(result.data["notice"]) == 20

    keyword = "성서봇"
    encoded_keyword = quote(keyword)
    response = await MainNotice.fetch(page="1", search_keyword=keyword)
    assert response.status == 200

    result = MainNotice.parse(response)
    assert result.meta["page"] == "1"
    assert result.meta["keyword"] == keyword
    assert len(result.data["notice"]) > 0
    assert encoded_keyword == result.link[-len(encoded_keyword) :]


async def test_scholarship_notice():
    response = await ScholarshipNotice.fetch()
    assert response.status == 200

    result = ScholarshipNotice.parse(response)
    assert result.meta["page"] == "1"
    assert result.meta["keyword"] is None
    assert len(result.data["notice"]) == 20

    response = await ScholarshipNotice.fetch(page="2")
    assert response.status == 200

    result = ScholarshipNotice.parse(response)
    assert result.meta["page"] == "2"
    assert result.meta["keyword"] is None
    assert len(result.data["notice"]) == 20

    keyword = '"푸른등대 삼성SOS장학사업 신규 장학생 선발 공고"'
    encoded_keyword = encode_kbustyle(keyword)

    response = await ScholarshipNotice.fetch(page="1", search_keyword=keyword)
    assert response.status == 200

    result = ScholarshipNotice.parse(response)
    assert result.meta["page"] == "1"
    assert result.meta["keyword"] == keyword
    assert len(result.data["notice"]) > 0
    assert encoded_keyword == result.link[-len(encoded_keyword) :]


async def test_illip_notice():
    response = await IllipNotice.fetch()
    assert response.status == 200

    result = IllipNotice.parse(response)
    assert result.meta["page"] == "1"
    assert result.meta["keyword"] is None
    assert len(result.data["notice"]) == 20

    response = await IllipNotice.fetch(page="2")
    assert response.status == 200

    result = IllipNotice.parse(response)
    assert result.meta["page"] == "2"
    assert result.meta["keyword"] is None
    assert len(result.data["notice"]) == 20

    keyword = '"신앙훈련 공지"'
    encoded_keyword = encode_kbustyle(keyword)
    response = await IllipNotice.fetch(page="1", search_keyword=keyword)
    assert response.status == 200

    result = IllipNotice.parse(response)
    assert result.meta["page"] == "1"
    assert result.meta["keyword"] == keyword
    assert len(result.data["notice"]) > 0
    assert encoded_keyword == result.link[-len(encoded_keyword) :]


async def test_notice_article():
    url = "https://www.bible.ac.kr/ko/life/notice/view/34114?p=1"
    response = await NoticeArticle.fetch(url)
    assert response.status == 200
    result = NoticeArticle.parse(response)
    assert result.title == "[학사] 2020학년도 1학기 개강 연기 안내"
    assert result.author == "김병수"
    assert result.date == datetime.datetime(2020, 2, 21, 9, 27)
    print(result)
    return result


async def main():
    await test_main_notice()
    await test_scholarship_notice()
    await test_illip_notice()
    await test_notice_article()


asyncio.run(main())



__all__ = (
    "__title__",
    "__description__",
    "__url__",
    "__version__",
    "__author__",
    "__author_email__",
    "__license__",
    "__copyright__",
)

__title__ = "biblebot"
__description__ = "Scraper for KBU students"
__url__ = "https://github.com/rekyungmin/biblebot-scraper"
__version__ = "0.1.5"
__author__ = "Kyungmin Lee"
__author_email__ = "rekyungmin@gmail.com"
__license__ = "MIT"
__copyright__ = "Copyright 2020 Kyungmin Lee"



import asyncio

from biblebot.api.lms import *
from biblebot.api.base import ErrorData, ResourceData


async def test_login(user_id, user_pw):
    # 비밀번호 틀린 경우
    response = await Login.fetch(user_id, user_pw + "123")
    assert response.status == 303
    result = Login.parse(response)
    assert isinstance(result, ErrorData)
    print(result)
    # assert result.error["title"] == "비밀번호가 일치하지 않습니다."

    # 아이디가 다른 경우
    response = await Login.fetch(user_id + "1a2b3c", user_pw)
    # assert response.status == 303
    result = Login.parse(response)
    print(result)

    assert isinstance(result, ErrorData)
    # assert result.error["title"] == "존재하지 않는 회원ID 입니다."

    # 정상 로그인
    response = await Login.fetch(user_id, user_pw)
    # assert response.status == 303
    assert response.cookies
    result = Login.parse(response)
    assert isinstance(result, ResourceData)
    assert result.data["cookies"]
    assert result.data["iat"]
    print(result)

    return response


async def test_profile(cookies):
    response = await Profile.fetch(cookies)
    result = Profile.parse(response)
    assert response.status == 200
    assert result.data["sid"] == "201504021"
    assert result.data["name"] == "이경민"
    assert result.data["major"] == "컴퓨터소프트웨어학과"

    result = Profile.parse_sid(response)
    assert result.data["sid"] == "201504021"

    result = Profile.parse_name(response)
    assert result.data["name"] == "이경민"

    result = Profile.parse_major(response)
    assert result.data["major"] == "컴퓨터소프트웨어학과"


async def test_courselist(cookies):
    response = await CourseList.fetch(cookies)
    result = CourseList.parse(response)
    assert response.status == 200
    assert result.data["courses"]
    assert result.meta["selected"]
    assert result.meta["selectable"]

    response = await CourseList.fetch(cookies, semester="20192")
    result = CourseList.parse(response)
    assert response.status == 200
    assert result.meta["selected"] == "20192"
    assert result.meta["selectable"]
    print(result)


async def test_attendance(cookies):
    course = {
        "경건훈련": "558",
        "전도훈련Ⅵ": "656",
        "세계문명과기독교Ⅱ": "706",
        "그린IT의이해": "782",
        "네트워크프로그래밍": "820",
        "미래설계상담": "824",
        "무선및모바일통신": "834",
        "데이터마이닝과통계": "836",
    }
    response = await Attendance.fetch(cookies, "836")
    assert response.status == 200
    result = Attendance.parse(response)
    assert isinstance(result, ResourceData)

    response = await Attendance.fetch(cookies, "837")
    assert response.status == 303
    result = Attendance.parse(response)
    assert isinstance(result, ErrorData)


async def test_invalid_cookies():
    invalid_cookies = {"MoodleSession": "4cqrodtjrshs6agk4si6ga3ln3"}

    response = await Profile.fetch(invalid_cookies)
    result = Profile.parse(response)
    assert response.status == 303
    assert isinstance(result, ErrorData)

    result = Profile.parse_sid(response)
    assert isinstance(result, ErrorData)

    result = Profile.parse_name(response)
    assert isinstance(result, ErrorData)

    result = Profile.parse_major(response)
    assert isinstance(result, ErrorData)

    response = await CourseList.fetch(invalid_cookies)
    result = CourseList.parse(response)
    assert isinstance(result, ErrorData)

    response = await CourseList.fetch(invalid_cookies, semester="20192")
    result = CourseList.parse(response)
    assert isinstance(result, ErrorData)

    response = await Attendance.fetch(invalid_cookies, "836")
    result = Attendance.parse(response)
    assert isinstance(result, ErrorData)


async def main():
    response = await test_login("ramming125", "gksrlghd123")
    cookies = response.cookies
    await test_profile(cookies)
    await test_courselist(cookies)
    await test_attendance(cookies)
    await test_invalid_cookies()


asyncio.run(main())



import asyncio
from dataclasses import field, asdict

from http.cookies import SimpleCookie

from biblebot.reqeust.aiohttp_conn import *


async def main():
    data = {"Txt_1": "ramming125", "Txt_2": "gksrlghd123", "use_type": "3"}
    resp = await Request.get(
        "https://www.cultizm.com/kor/denim/jeans/7821/a.p.c.-petit-new-standard-indigo-red-selvage-14.5oz",
        # body=data,
        verify=False,
        allow_redirects=False,
        timeout=30.0,
    )
    print(resp.text)
    print(resp.headers)
    cookies = resp.cookies

    resp = await Request.get(
        "http://kbuis.bible.ac.kr/SchoolRegMng/SR020.aspx", cookies=cookies
    )


asyncio.run(main())
